Index: /trunk/src/VBox/Frontends/VBoxBalloonCtrl/VBoxBalloonCtrl.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VBoxBalloonCtrl/VBoxBalloonCtrl.cpp	(revision 36701)
+++ /trunk/src/VBox/Frontends/VBoxBalloonCtrl/VBoxBalloonCtrl.cpp	(revision 36702)
@@ -73,5 +73,5 @@
 
 static uint32_t      g_cHistory = 10;                   /* Enable log rotation, 10 files. */
-static uint32_t      g_uHistoryFileTime = RT_SEC_1WEEK; /* Max 1 week per file. */
+static uint32_t      g_uHistoryFileTime = RT_SEC_1DAY;  /* Max 1 day per file. */
 static uint64_t      g_uHistoryFileSize = 100 * _1M;    /* Max 100MB per file. */
 
@@ -112,5 +112,10 @@
     /** Global max. balloon limit. */
     { "--balloon-max",          GETOPTDEF_BALLOONCTRL_BALLOONMAX,          RTGETOPT_REQ_INT32 },
-    { "--verbose",              'v',                                       RTGETOPT_REQ_NOTHING }
+    { "--verbose",              'v',                                       RTGETOPT_REQ_NOTHING },
+    { "--pidfile",              'P',                                       RTGETOPT_REQ_STRING },
+    { "--logfile",              'F',                                       RTGETOPT_REQ_STRING },
+    { "--logrotate",            'R',                                       RTGETOPT_REQ_UINT32 },
+    { "--logsize",              'S',                                       RTGETOPT_REQ_UINT64 },
+    { "--loginterval",          'I',                                       RTGETOPT_REQ_UINT32 }
 };
 
@@ -1006,4 +1011,24 @@
                 pcszDescr = "Sets the balloon maximum limit in MB (0 MB).";
                 break;
+
+            case 'P':
+                pcszDescr = "Name of the PID file which is created when the daemon was started.";
+                break;
+
+            case 'F':
+                pcszDescr = "Name of file to write log to (no file).";
+                break;
+
+            case 'R':
+                pcszDescr = "Number of log files (0 disables log rotation).";
+                break;
+
+            case 'S':
+                pcszDescr = "Maximum size of a log file to trigger rotation (bytes).";
+                break;
+
+            case 'I':
+                pcszDescr = "Maximum time interval to trigger log rotation (seconds).";
+                break;
         }
 
@@ -1079,4 +1104,24 @@
                 break;
 
+            case 'P':
+                pszPidFile = ValueUnion.psz;
+                break;
+
+            case 'F':
+                pszLogFile = ValueUnion.psz;
+                break;
+
+            case 'R':
+                g_cHistory = ValueUnion.u32;
+                break;
+
+            case 'S':
+                g_uHistoryFileSize = ValueUnion.u64;
+                break;
+
+            case 'I':
+                g_uHistoryFileTime = ValueUnion.u32;
+                break;
+
             default:
                 rc = RTGetOptPrintError(c, &ValueUnion);
Index: /trunk/src/VBox/Main/webservice/vboxweb.cpp
===================================================================
--- /trunk/src/VBox/Main/webservice/vboxweb.cpp	(revision 36701)
+++ /trunk/src/VBox/Main/webservice/vboxweb.cpp	(revision 36702)
@@ -112,5 +112,5 @@
 
 uint32_t                g_cHistory = 10;                // enable log rotation, 10 files
-uint32_t                g_uHistoryFileTime = RT_SEC_1WEEK; // max 1 week per file
+uint32_t                g_uHistoryFileTime = RT_SEC_1DAY; // max 1 day per file
 uint64_t                g_uHistoryFileSize = 100 * _1M; // max 100MB per file
 bool                    g_fVerbose = false;             // be verbose
@@ -250,5 +250,5 @@
 
             case 'S':
-                pcszDescr = "Maximum size of a log file to trigger rotationi (bytes).";
+                pcszDescr = "Maximum size of a log file to trigger rotation (bytes).";
                 break;
 
@@ -828,8 +828,6 @@
 
             case 'F':
-            {
                 pszLogFile = ValueUnion.psz;
                 break;
-            }
 
             case 'R':
